@@ -44,7 +44,7 @@ $lang = array_merge($lang, array(
 	'DEFAULT_LANGUAGE'				=> 'Varsayılan dil',
 	'DEFAULT_STYLE'					=> 'Varsayılan stil',
 	'DISABLE_BOARD'					=> 'Mesaj panosunu kullanıcılara kapat',
-	'DISABLE_BOARD_EXPLAIN'			=> 'Bu işlem, mesaj panosunu kullanıcılara kapatacaktır. İsterseniz, kapama nedeni olarak kullanıcıların görebileceği kısa bir mesaj (255 karakter) yazabilirsiniz.',
+	'DISABLE_BOARD_EXPLAIN'			=> 'Bu işlem, mesaj panosunu yönetici ve moderatör olmayan tüm kullanıcılara kapatacaktır. İsterseniz, kapama nedeni olarak kullanıcıların görebileceği kısa bir mesaj (255 karakter) yazabilirsiniz.',
 	'OVERRIDE_STYLE'				=> 'Kullanıcı stilini gözardı et',
 	'OVERRIDE_STYLE_EXPLAIN'		=> 'Kullanıcıların stillerini varsayılan ile değiştirir.',
 	'SITE_DESC'						=> 'Mesaj panosu açıklaması',
@@ -104,7 +104,7 @@ $lang = array_merge($lang, array(
 	'AVATAR_GALLERY_PATH'			=> 'Avatar galerisinin klasörü',
 	'AVATAR_GALLERY_PATH_EXPLAIN'	=> 'Ön-yüklenmiş resimler için phpBB ana klasörünüzün alt yolu, örnek: <samp>images/avatars/gallery</samp>.',
 	'AVATAR_STORAGE_PATH'			=> 'Avatar kayıt klasörü',
-	'AVATAR_STORAGE_PATH_EXPLAIN'	=> 'phpBB ana klasörünüzün alt yolu, örnek: <samp>images/avatars/upload</samp>.',
+	'AVATAR_STORAGE_PATH_EXPLAIN'	=> 'phpBB ana dizininizin alt yolu, örnek: <samp>images/avatars/upload</samp>.<br />Eğer bu yol yazılabilir değilse avatar yüklemesi <strong>yapılamayacaktır</strong>.',
 	'MAX_AVATAR_SIZE'				=> 'En yüksek avatar boyutları',
 	'MAX_AVATAR_SIZE_EXPLAIN'		=> 'Piksel cinsinden Genişlik x Yükseklik.',
 	'MAX_FILESIZE'					=> 'En yüksek avatar dosyası büyüklüğü',
