@@ -49,9 +49,9 @@ $lang = array_merge($lang, array(
 	'ACP_BACKUP'				=> 'Yedekleme',
 	'ACP_BAN'					=> 'Yasaklama',
 	'ACP_BAN_EMAILS'			=> 'E-postaları yasakla',
-	'ACP_BAN_IPS'				=> 'IP\'leri yasakla',
-	'ACP_BAN_USERNAMES'			=> 'Kullanıcı adlarını yasakla',
-	'ACP_BBCODES'				=> 'BBCode\'lar',
+	'ACP_BAN_IPS'				=> 'IPleri yasakla',
+	'ACP_BAN_USERNAMES'			=> 'Kullanıcıları yasakla',
+	'ACP_BBCODES'				=> 'BBCodelar',
 	'ACP_BOARD_CONFIGURATION'	=> 'Mesaj panosu konfigürasyonu',
 	'ACP_BOARD_FEATURES'		=> 'Mesaj panosu özellikleri',
 	'ACP_BOARD_MANAGEMENT'		=> 'Mesaj panosu yönetimi',
