@@ -88,9 +88,10 @@ $lang = array_merge($lang, array(
 	'AVATAR_PARTIAL_UPLOAD'			=> 'Belirtilen dosyanın sadece bir kısmı yüklendi.',
 	'AVATAR_PHP_SIZE_NA'			=> 'Avatar dosya boyutu çok büyük.<br />php.ini dosyasında ayarlanmış izin verilen en yüksek dosya boyutu belirlenemiyor.',
 	'AVATAR_PHP_SIZE_OVERRUN'		=> 'Avatar dosya boyutu çok büyük. İzin verilen en yüksek yükleme boyutu %1$d %2$s.<br />Not: Bu ayar php.ini dosyasında belirlenmiştir ve üzerine yazılamaz.',
+	'AVATAR_REMOTE_UPLOAD_TIMEOUT'		=> 'Belirtilen avatar yüklenemedi, çünkü istek zaman aşımına uğradı.',
 	'AVATAR_URL_INVALID'			=> 'Belirtilen URL hatalı.',
 	'AVATAR_URL_NOT_FOUND'			=> 'Belirtilen dosya bulunamıyor.',
-	'AVATAR_WRONG_FILESIZE'			=> 'Avatarın dosya boyutu 0 ve %1d %2s arasında olmalıdır.',
+	'AVATAR_WRONG_FILESIZE'			=> 'Avatar’ın dosya boyutu 0 ve %1$d %2$s arasında olmalıdır.',
 	'AVATAR_WRONG_SIZE'			=> 'Eklenen avatar %5$d piksel genişliğinde ve %6$d piksel yüksekliğinde. Avatarlar en az %1$d piksel genişliğinde ve %2$d piksel yüksekliğinde olmalıdır, fakat %3$d piksel genişliğinden ve %4$d piksel yüksekliğinden fazla olamaz.',
 
 	'BACK_TO_TOP'			=> 'Başa Dön',
@@ -341,6 +342,9 @@ $lang = array_merge($lang, array(
 	'MODERATE'			=> 'Yönet',
 	'MODERATOR'			=> 'Moderatör',
 	'MODERATORS'		=> 'Moderatörler',
+ 	'MODULE_NOT_ACCESS'		=> 'Modül erişilebilir değil',
+ 	'MODULE_NOT_FIND'		=> '%s modülü bulunamıyor',
+ 	'MODULE_FILE_INCORRECT_CLASS'	=> '%s modül dosyası doğru sınıf içermiyor [%s]',	
 	'MONTH'				=> 'Ay',
 	'MOVE'				=> 'Taşı',
 	'MSNM'					=> 'MSNM/WLM',
@@ -647,7 +651,7 @@ $lang = array_merge($lang, array(
 	'TOTAL_USERS_ZERO'	=> 'Toplam <strong>0</strong> üye',
 	'TRACKED_PHP_ERROR'	=> 'İzlenen PHP hataları: %s',
 
-	'UNABLE_GET_IMAGE_SIZE'	=> 'Resmin boyutlarının belirlenmesi mümkün değil.',
+	'UNABLE_GET_IMAGE_SIZE'	=> 'Resmin boyutlarını belirlemek mümkün olmadı. Lütfen girdiğiniz URL adresinin geçerli olup olmadığını kontrol edin.',
 	'UNABLE_TO_DELIVER_FILE'=> 'Dosya teslim edilemiyor.',
 	'UNKNOWN_BROWSER'		=> 'Bilinmeyen Tarayıcı',
 	'UNMARK_ALL'			=> 'Tüm işaretleri kaldır',
